@@ -5,16 +5,16 @@ from django.views.generic.simple import direct_to_template
 # lfs imports
 from lfs.core.sitemap import ProductSitemap
 from lfs.core.sitemap import CategorySitemap
-from lfs.contact_form.forms import ContactForm
+from lfs.core.views import one_time_setup
 
 # Robots
 urlpatterns = patterns('django.views.generic.simple',
-    (r'^robots.txt', 'direct_to_template', { 'template': 'lfs/shop/robots.txt' }),
+    (r'^robots.txt', 'direct_to_template', {'template': 'lfs/shop/robots.txt'}),
 )
 
 # Sitemaps
 urlpatterns += patterns("django.contrib.sitemaps.views",
-    url(r'^sitemap.xml$', 'sitemap', {'sitemaps': {"products": ProductSitemap, "categories" : CategorySitemap }})
+    url(r'^sitemap.xml$', 'sitemap', {'sitemaps': {"products": ProductSitemap, "categories": CategorySitemap}})
 )
 
 # Shop
@@ -30,13 +30,12 @@ urlpatterns += patterns('lfs.cart.views',
     url(r'^delete-cart-item/(?P<cart_item_id>\d*)$', "delete_cart_item", name="lfs_delete_cart_item"),
     url(r'^refresh-cart$', "refresh_cart"),
     url(r'^cart$', "cart", name="lfs_cart"),
-    url(r'^check-voucher-cart/$', "check_voucher", name="lfs_check_voucher_cart"),    
+    url(r'^check-voucher-cart/$', "check_voucher", name="lfs_check_voucher_cart"),
 )
 
 # Catalog
 urlpatterns += patterns('lfs.catalog.views',
     url(r'^category-(?P<slug>[-\w]*)$', "category_view", name="lfs_category"),
-    url(r'^get-categories-nodes$', "get_category_nodes"),
     url(r'^product/(?P<slug>[-\w]*)$', "product_view", name="lfs_product"),
     url(r'^product-form-dispatcher', "product_form_dispatcher", name="lfs_product_dispatcher"),
     url(r'^set-sorting', "set_sorting", name="lfs_catalog_set_sorting"),
@@ -47,8 +46,8 @@ urlpatterns += patterns('lfs.catalog.views',
     url(r'^reset-product-filter/(?P<category_slug>[-\w]+)/(?P<property_id>\d+)', "reset_filter", name="lfs_reset_product_filter"),
     url(r'^reset-all-product-filter/(?P<category_slug>[-\w]+)', "reset_all_filter", name="lfs_reset_all_product_filter"),
     url(r'^select-variant$', "select_variant", name="lfs_select_variant"),
-    url(r'^select-variant-from-properties$', "select_variant_from_properties", name="lfs_select_variant_from_properties"),    
-    url(r'^file/(?P<id>[-\w]*)', "file", name="lfs_file"),    
+    url(r'^select-variant-from-properties$', "select_variant_from_properties", name="lfs_select_variant_from_properties"),
+    url(r'^file/(?P<id>[-\w]*)', "file", name="lfs_file"),
     url(r'^calculate-price/(?P<id>[-\w]*)', "calculate_price", name="lfs_calculate_price"),
     url(r'^calculate-packing/(?P<id>[-\w]*)', "calculate_packing", name="lfs_calculate_packing"),
 )
@@ -58,19 +57,16 @@ urlpatterns += patterns('lfs.checkout.views',
     url(r'^checkout-dispatcher', "checkout_dispatcher", name="lfs_checkout_dispatcher"),
     url(r'^checkout-login', "login", name="lfs_checkout_login"),
     url(r'^checkout', "one_page_checkout", name="lfs_checkout"),
-    url(r'^thank-you', "thank_you",name="lfs_thank_you"),
+    url(r'^thank-you', "thank_you", name="lfs_thank_you"),
     url(r'^changed-checkout/$', "changed_checkout", name="lfs_changed_checkout"),
-    url(r'^check-voucher/$', "check_voucher", name="lfs_check_voucher"),    
-)
-
-urlpatterns += patterns('contact_form.views',
-    url(r'^contact/$', "contact_form", { "form_class" : ContactForm }, name='contact_form'),
-    url(r'^sent/$', direct_to_template, { 'template': 'contact_form/contact_form_sent.html' }, name='contact_form_sent'),
+    url(r'^changed-invoice-country/$', "changed_invoice_country", name="lfs_changed_invoice_country"),
+    url(r'^changed-shipping-country/$', "changed_shipping_country", name="lfs_changed_shipping_country"),
+    url(r'^check-voucher/$', "check_voucher", name="lfs_check_voucher"),
 )
 
 # Customer
 urlpatterns += patterns('lfs.customer.views',
-    url(r'^login',  "login", name="lfs_login"),
+    url(r'^login', "login", name="lfs_login"),
     url(r'^logout', "logout", name="lfs_logout"),
     url(r'^my-account', "account", name="lfs_my_account"),
     url(r'^my-addresses', "addresses", name="lfs_my_addresses"),
@@ -104,4 +100,21 @@ urlpatterns += patterns('lfs.search.views',
 # Tagging
 urlpatterns += patterns('',
     (r'^tagging/', include('lfs.tagging.urls')),
-)
\ No newline at end of file
+)
+
+# Catalog REST API
+urlpatterns += patterns('',
+    (r'^catalog/api/', include('lfs.catalog.api.urls')),
+)
+
+# Manage REST API
+urlpatterns += patterns('',
+    (r'^manage/api/', include('lfs.manage.api.urls')),
+)
+
+urlpatterns += patterns('',
+    (r'', include('lfs_contact.urls')),
+)
+
+
+one_time_setup()
