@@ -6,13 +6,30 @@ from django.core.urlresolvers import reverse
 from django.core import mail
 
 # lfs imports
-from lfs.core.models import Shop, Country
-from lfs.customer.models import Customer, Address
+from lfs.core.models import Country
+from lfs.core.models import Shop
+from lfs.customer.models import Address
+from lfs.customer.models import CreditCard
+from lfs.customer.models import Customer
 from lfs.shipping.models import ShippingMethod
 from lfs.tax.models import Tax
 from lfs.payment.models import PaymentMethod
 
 
+class CreditCardTestCase(TestCase):
+    def setUp(self):
+        self.cc = CreditCard(
+            type = "mastercard",
+            owner = "John Doe",
+            number = "4711",
+            expiration_date_month = 8,
+            expiration_date_year = 2012
+        )
+
+    def test_unicode(self):
+        self.assertEquals(self.cc.__unicode__(), "%s / %s" % (self.cc.type, self.cc.owner))
+
+
 class AddressTestCase(TestCase):
 
     fixtures = ['lfs_shop.xml']
