@@ -10,6 +10,7 @@ from django.template import RequestContext
 from django.template.loader import render_to_string
 from django.utils import simplejson
 from django.utils.translation import ugettext_lazy as _
+from django.views.decorators.http import require_POST
 
 # lfs imports
 import lfs.core.utils
@@ -23,6 +24,7 @@ from lfs.export.models import CategoryOption
 from lfs.export.settings import CATEGORY_VARIANTS_CHOICES
 from lfs.export.settings import CATEGORY_VARIANTS_NONE
 
+
 class ExportDataForm(ModelForm):
     """Form to manage selection data.
     """
@@ -30,6 +32,7 @@ class ExportDataForm(ModelForm):
         model = Export
         exclude = ("products", )
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def manage_export(request, export_id, template_name="manage/export/export.html"):
     """The main view to display exports.
@@ -43,7 +46,7 @@ def manage_export(request, export_id, template_name="manage/export/export.html")
         options = []
 
         try:
-            category_option = CategoryOption.objects.get(export = export, category = category)
+            category_option = CategoryOption.objects.get(export=export, category=category)
         except CategoryOption.DoesNotExist:
             variants_option = None
         else:
@@ -51,50 +54,53 @@ def manage_export(request, export_id, template_name="manage/export/export.html")
 
         for option in CATEGORY_VARIANTS_CHOICES:
             options.append({
-                "name" : option[1],
-                "value" : option[0],
-                "selected" : option[0] == variants_option,
+                "name": option[1],
+                "value": option[0],
+                "selected": option[0] == variants_option,
             })
 
         # Checking state
         checked, klass = _get_category_state(export, category)
 
         categories.append({
-            "id" : category.id,
-            "name" : category.name,
-            "checked" : checked,
-            "klass" : klass,
-            "options" : options,
+            "id": category.id,
+            "name": category.name,
+            "checked": checked,
+            "klass": klass,
+            "options": options,
         })
 
     data_form = ExportDataForm(instance=export)
     return render_to_response(template_name, RequestContext(request, {
-        "categories" : categories,
-        "export_id" : export_id,
-        "slug" : export.slug,
-        "selectable_exports_inline" : selectable_exports_inline(request, export_id),
-        "export_data_inline" : export_data_inline(request, export_id, data_form),
+        "categories": categories,
+        "export_id": export_id,
+        "slug": export.slug,
+        "selectable_exports_inline": selectable_exports_inline(request, export_id),
+        "export_data_inline": export_data_inline(request, export_id, data_form),
     }))
 
+
 # Parts
 def export_data_inline(request, export_id, form,
     template_name="manage/export/export_data_inline.html"):
     """Displays the data form of the current export.
     """
     return render_to_string(template_name, RequestContext(request, {
-        "export_id" : export_id,
-        "form" : form,
+        "export_id": export_id,
+        "form": form,
     }))
 
+
 def selectable_exports_inline(request, export_id,
     template_name="manage/export/selectable_exports_inline.html"):
     """Displays all selectable exports.
     """
     return render_to_string(template_name, RequestContext(request, {
-        "exports" : Export.objects.all(),
-        "export_id" : int(export_id),
+        "exports": Export.objects.all(),
+        "export_id": int(export_id),
     }))
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def export_inline(request, export_id, category_id,
     template_name="manage/export/export_inline.html"):
@@ -112,10 +118,10 @@ def export_inline(request, export_id, category_id,
             type = "V"
 
         products.append({
-            "id" : product.id,
-            "name" : product.get_name(),
-            "checked" : product in selected_products,
-            "type" : type,
+            "id": product.id,
+            "name": product.get_name(),
+            "checked": product in selected_products,
+            "type": type,
         })
 
     categories = []
@@ -125,7 +131,7 @@ def export_inline(request, export_id, category_id,
         options = []
 
         try:
-            category_option = CategoryOption.objects.get(export = export, category = category)
+            category_option = CategoryOption.objects.get(export=export, category=category)
         except CategoryOption.DoesNotExist:
             variants_option = None
         else:
@@ -133,31 +139,32 @@ def export_inline(request, export_id, category_id,
 
         for option in CATEGORY_VARIANTS_CHOICES:
             options.append({
-                "name" : option[1],
-                "value" : option[0],
-                "selected" : option[0] == variants_option,
+                "name": option[1],
+                "value": option[0],
+                "selected": option[0] == variants_option,
             })
 
         checked, klass = _get_category_state(export, category)
 
         categories.append({
-            "id" : category.id,
-            "name" : category.name,
-            "checked" : checked,
-            "klass" : klass,
-            "options" : options,
+            "id": category.id,
+            "name": category.name,
+            "checked": checked,
+            "klass": klass,
+            "options": options,
         })
 
     result = render_to_string(template_name, RequestContext(request, {
-        "categories" : categories,
-        "products" : products,
-        "export_id" : export_id,
+        "categories": categories,
+        "products": products,
+        "export_id": export_id,
     }))
 
     html = (("#sub-categories-%s" % category_id, result),)
 
     return HttpResponse(
-        simplejson.dumps({ "html" : html }))
+        simplejson.dumps({"html": html}))
+
 
 @permission_required("core.manage_shop", login_url="/login/")
 def add_export(request, template_name="manage/export/add_export.html"):
@@ -168,16 +175,17 @@ def add_export(request, template_name="manage/export/add_export.html"):
         if form.is_valid():
             new_export = form.save()
             return HttpResponseRedirect(
-                reverse("lfs_export", kwargs={ "export_id" : new_export.id }))
+                reverse("lfs_export", kwargs={"export_id": new_export.id}))
 
     else:
         form = ExportDataForm()
 
     return render_to_response(template_name, RequestContext(request, {
-        "form" : form,
-        "selectable_exports_inline" : selectable_exports_inline(request, 0),
+        "form": form,
+        "selectable_exports_inline": selectable_exports_inline(request, 0),
     }))
 
+
 # Actions
 @permission_required("core.manage_shop", login_url="/login/")
 def export_dispatcher(request):
@@ -189,9 +197,11 @@ def export_dispatcher(request):
         return HttpResponseRedirect(reverse("lfs_export_add_export"))
     else:
         return HttpResponseRedirect(
-            reverse("lfs_export", kwargs = {"export_id" : export.id }))
+            reverse("lfs_export", kwargs={"export_id": export.id}))
+
 
 @permission_required("core.manage_shop", login_url="/login/")
+@require_POST
 def delete_export(request, export_id):
     """Deletes export with passed export id.
     """
@@ -204,6 +214,7 @@ def delete_export(request, export_id):
 
     return HttpResponseRedirect(reverse("lfs_export_dispatcher"))
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def edit_category(request, export_id, category_id):
     """Adds/Removes products of given category to given export.
@@ -220,6 +231,7 @@ def edit_category(request, export_id, category_id):
 
     return HttpResponse("")
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def edit_product(request, export_id, product_id):
     """Adds/Removes given product to given export.
@@ -234,6 +246,7 @@ def edit_product(request, export_id, product_id):
 
     return HttpResponse("")
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def export(request, slug):
     """Exports the export with passed export id.
@@ -242,6 +255,7 @@ def export(request, slug):
     module = lfs.core.utils.import_module(export.script.module)
     return getattr(module, export.script.method)(request, export)
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def category_state(request, export_id, category_id):
     """Sets the state (klass and checking) for given category for given
@@ -261,11 +275,12 @@ def category_state(request, export_id, category_id):
 
     return HttpResponse(
         simplejson.dumps({
-            "html" : html,
-            "checkbox" : checkbox
+            "html": html,
+            "checkbox": checkbox
         })
     )
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def update_category_variants_option(request, export_id, category_id):
     """Stores / deletes options for the variants handling of category with
@@ -287,7 +302,7 @@ def update_category_variants_option(request, export_id, category_id):
         return HttpResponse("")
 
     try:
-        category_option = CategoryOption.objects.get(export = export, category = category)
+        category_option = CategoryOption.objects.get(export=export, category=category)
     except CategoryOption.DoesNotExist:
         category_option = None
 
@@ -297,13 +312,14 @@ def update_category_variants_option(request, export_id, category_id):
     else:
         if category_option is None:
             CategoryOption.objects.create(
-                export = export, category = category, variants_option = variants_option)
+                export=export, category=category, variants_option=variants_option)
         else:
             category_option.variants_option = variants_option
             category_option.save()
 
     return HttpResponse("")
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def update_data(request, export_id):
     """Updates data of export with given export id.
@@ -322,12 +338,13 @@ def update_data(request, export_id):
     )
 
     result = simplejson.dumps({
-        "html" : html,
-        "message" : msg
-    }, cls = LazyEncoder)
+        "html": html,
+        "message": msg
+    }, cls=LazyEncoder)
 
     return HttpResponse(result)
 
+
 def _get_category_state(export, category):
     """Calculates the state for given category for given export.
     """
