@@ -1,13 +1,14 @@
 # django imports
 from django import forms
+from django.template import RequestContext
 from django.template.loader import render_to_string
 
 # portlets imports
 from portlets.models import Portlet
-from portlets.utils import register_portlet
+
 
 class RelatedProductsPortlet(Portlet):
-    """A portlet to display related products.
+    """Portlet to display related products.
     """
     class Meta:
         app_label = 'portlet'
@@ -19,20 +20,19 @@ class RelatedProductsPortlet(Portlet):
         """Renders the portlet as html.
         """
         product = context.get("product")
+        request = context.get("request")
 
-        return render_to_string("lfs/portlets/related_products.html", {
-            "title" : self.title,
-            "product" : product,
-            "MEDIA_URL" : context.get("MEDIA_URL"),
-        })
+        return render_to_string("lfs/portlets/related_products.html", RequestContext(request, {
+            "title": self.title,
+            "product": product,
+        }))
 
     def form(self, **kwargs):
-        """
-        """
         return RelatedProductsForm(instance=self, **kwargs)
 
+
 class RelatedProductsForm(forms.ModelForm):
-    """
+    """Form for the RelatedProductsPortlet.
     """
     class Meta:
         model = RelatedProductsPortlet
